@@ -22,7 +22,7 @@ from nowcasting_dataset.data_sources.fake.utils import (
 )
 from nowcasting_dataset.data_sources.gsp.eso import get_gsp_metadata_from_eso
 from nowcasting_dataset.data_sources.gsp.gsp_model import GSP
-from nowcasting_dataset.data_sources.metadata.metadata_model import Metadata
+from nowcasting_dataset.data_sources.metadata.metadata_model import Metadata, SpaceTimeLocation
 from nowcasting_dataset.data_sources.nwp.nwp_model import NWP
 from nowcasting_dataset.data_sources.optical_flow.optical_flow_model import OpticalFlow
 from nowcasting_dataset.data_sources.pv.pv_model import PV
@@ -108,9 +108,9 @@ def gsp_fake(
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        t0_datetimes_utc = metadata.t0_datetimes_utc
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_datasets = [
@@ -157,13 +157,17 @@ def metadata_fake(
         # choose random index
         index = np.random.choice(len(metadata), size=batch_size)
 
-        lat = metadata.iloc[index].centroid_lat
-        lon = metadata.iloc[index].centroid_lon
+        lat = list(metadata.iloc[index].centroid_lat)
+        lon = list(metadata.iloc[index].centroid_lon)
+        ids = list(metadata.iloc[index].index)
+        id_types = ["gsp"] * batch_size
 
     else:
         # get random OSGB center in the UK
         lat = np.random.uniform(51, 55, batch_size)
         lon = np.random.uniform(-2.5, 1, batch_size)
+        ids = [None] * batch_size
+        id_types = [None] * batch_size
 
     x_centers_osgb, y_centers_osgb = lat_lon_to_osgb(lat=lat, lon=lon)
 
@@ -172,13 +176,19 @@ def metadata_fake(
         batch_size=batch_size, temporally_align_examples=temporally_align_examples
     )
 
-    metadata_dict = {}
-    metadata_dict["batch_size"] = batch_size
-    metadata_dict["x_center_osgb"] = list(x_centers_osgb)
-    metadata_dict["y_center_osgb"] = list(y_centers_osgb)
-    metadata_dict["t0_datetime_utc"] = list(t0_datetimes_utc)
+    # would be good to parrelize this
+    locations = [
+        SpaceTimeLocation(
+            t0_datetime_utc=t0_datetimes_utc[i],
+            x_center_osgb=x_centers_osgb[i],
+            y_center_osgb=y_centers_osgb[i],
+            id=ids[i],
+            id_type=id_types[i],
+        )
+        for i in range(0, batch_size)
+    ]
 
-    return Metadata(**metadata_dict)
+    return Metadata(batch_size=batch_size, space_time_locations=locations)
 
 
 def nwp_fake(
@@ -201,9 +211,9 @@ def nwp_fake(
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        t0_datetimes_utc = metadata.t0_datetimes_utc
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_arrays = [
@@ -248,9 +258,9 @@ def pv_fake(
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        t0_datetimes_utc = metadata.t0_datetimes_utc
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_datasets = [
@@ -296,9 +306,9 @@ def satellite_fake(
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        t0_datetimes_utc = metadata.t0_datetimes_utc
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_arrays = [
@@ -340,9 +350,9 @@ def hrv_satellite_fake(
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        t0_datetimes_utc = metadata.t0_datetimes_utc
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_arrays = [
@@ -385,9 +395,9 @@ def optical_flow_fake(
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        t0_datetimes_utc = metadata.t0_datetimes_utc
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_arrays = [
@@ -421,7 +431,7 @@ def sun_fake(
     if metadata is None:
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
     else:
-        t0_datetimes_utc = metadata.t0_datetime_utc
+        t0_datetimes_utc = metadata.t0_datetimes_utc
 
     # create dataset with both azimuth and elevation, index with time
     # make batch of arrays
@@ -442,8 +452,8 @@ def topographic_fake(batch_size, image_size_pixels, metadata: Optional[Metadata]
     if metadata is None:
         x_centers_osgb, y_centers_osgb = make_random_x_and_y_osgb_centers(batch_size)
     else:
-        x_centers_osgb = metadata.x_center_osgb
-        y_centers_osgb = metadata.y_center_osgb
+        x_centers_osgb = metadata.x_centers_osgb
+        y_centers_osgb = metadata.y_centers_osgb
 
     # make batch of arrays
     xr_arrays = []
